@@ -38,7 +38,7 @@ Try this::
 """
     raise SystemExit()
 
-__version__ = '0.2'
+__version__ = '0.3'
 
 SERVICE_LOGIN_BOX_URL = "https://www.google.com/accounts/ServiceLoginBox?service=adsense&ltmpl=login&ifr=true&rm=hide&fpui=3&nui=15&alwf=true&passive=true&continue=https%3A%2F%2Fwww.google.com%2Fadsense%2Flogin-box-gaiaauth&followup=https%3A%2F%2Fwww.google.com%2Fadsense%2Flogin-box-gaiaauth&hl=en_US"
 
@@ -88,7 +88,15 @@ def parse_summary_table(doc):
     res = []
     FIELDS = ['channel', 'impressions', 'clicks', 'ctr', 'ecpm', 'earnings']
     for row in t.findall('.//tr')[1:]:
-        celltext = [(c.text or c.findtext('a') or '').strip() for c in row.findall('td')]
+        celltext = []
+        for c in row.findall('td'):
+            tail = ''
+            # adsense inserts an empty span if a row has a period in it, so
+            # get the children and find the tail element to append to the text
+            if c.find('a') and c.find('a').getchildren():
+                tail = c.find('a').getchildren()[0].tail or ''
+            celltext.append('%s%s' % ((c.text or c.findtext('a') or '').strip(), tail.strip()))
+
         if len(celltext) != 6:
             continue
         try:
